@@ -13,7 +13,10 @@ FAKE_NEW_RUN = uuid4()
 
 
 class MockResponse:
-    def __init__(self, json_data: Union[Dict, List], status_code: int) -> None:
+    def __init__(
+        self, json_data: Union[Dict, List], status_code: int, headers: Dict = None
+    ) -> None:
+        self.headers = headers or {}
         self.json_data = json_data
         self.status_code = status_code
         if status_code in (200, 204):
@@ -25,16 +28,19 @@ class MockResponse:
     def json(self) -> Union[Dict, List]:
         return self.json_data
 
+    def raise_for_status(self) -> None:
+        pass
+
 
 def mocked_healthcheck_request(request_url: str) -> MockResponse:
-    if request_url.endswith("healthcheck"):
+    if request_url.endswith("healthcheck/runners"):
         return MockResponse({"api_version": __version__}, 200)
 
     return MockResponse({}, 200)
 
 
 def mocked_healthcheck_request_new_api_version(request_url: str) -> MockResponse:
-    if request_url.endswith("healthcheck"):
+    if request_url.endswith("healthcheck/runners"):
         return MockResponse({"api_version": "100.0.0"}, 200)
     return MockResponse({}, 200)
 
